<!doctype html>
<html lang="en">
<head>
    {% load static %}
    <meta charset="UTF-8">
    <meta name="viewport"
          content="width=device-width, user-scalable=no, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>sspaynow</title>
</head>
<style>
    html, body {
        height: 100%;
        font-family: monospace;
        background: #80808003;
    }

    .alert {
        display: flex;
        justify-content: center;
        align-items: center;
        flex-direction: column;
        height: 60%;
        width: auto;
        margin: auto;
    }

    h1 {
        margin-top: 20em;
        color: orange;
    }

    h3 {
        margin-bottom: 8em;
    }
    p {
        font-size: 12px;
        font-weight: 600;
    }
</style>
<body>
    <section class="alert">
        <h1><underline>website Under maintenance</underline></h1>
        <p>Our website is currently undergoing <span style="color: green;">sheduled maintenance</span></p>
        <p>We should be back shortly. Thank you for your patience</p>
        <img src="{% static 'maintenance/images/maintenance.gif' %}" width="500"  alt="">
        <h3>Application Id: DA-11542</h3>
    </section>

</body>
</html>